// SPDX-FileCopyrightText: 2023 Tobias Schmidl
//
// SPDX-License-Identifier: AGPL-3.0-or-later

#pragma once

#include <cstdint>
#include <map>
#include <string>

#include "glimpses/version.h"

namespace glimpses
{

/** @brief A class for saying retrieving system information */
class Glimpses
{
  public:
    /** @brief Type for representing the number of CPU cores. */
    using CPUCount = uint32_t;

    /** @brief Type for representing a set of CPU cores, mapped by their names. */
    using CPUSet = std::map<std::string, CPUCount>;

    /** @brief Maximum number of CPU cores supported by Glimpses. */
    constexpr static CPUCount MAX_CPU_COUNT = 1024;

    /** @brief Version of the Glimpses library. */
    constexpr static const char *VERSION = GLIMPSES_VERSION;

    /** @brief Creates a new glimpses */
    Glimpses();

    /**
     * @brief Returns the number of CPU cores available on the system.
     * @return The number of CPU cores available on the system.
     */
    CPUSet getCPUCount() const;
};

} // namespace glimpses
